'use strict';

function _interopDefault (ex) { return (ex && (typeof ex === 'object') && 'default' in ex) ? ex['default'] : ex; }

var axios = _interopDefault(require('axios'));

function _extends() {
  _extends = Object.assign || function (target) {
    for (var i = 1; i < arguments.length; i++) {
      var source = arguments[i];

      for (var key in source) {
        if (Object.prototype.hasOwnProperty.call(source, key)) {
          target[key] = source[key];
        }
      }
    }

    return target;
  };

  return _extends.apply(this, arguments);
}

function _inheritsLoose(subClass, superClass) {
  subClass.prototype = Object.create(superClass.prototype);
  subClass.prototype.constructor = subClass;
  subClass.__proto__ = superClass;
}

// A type of promise-like that resolves synchronously and supports only one observer

const _iteratorSymbol = /*#__PURE__*/ typeof Symbol !== "undefined" ? (Symbol.iterator || (Symbol.iterator = Symbol("Symbol.iterator"))) : "@@iterator";

const _asyncIteratorSymbol = /*#__PURE__*/ typeof Symbol !== "undefined" ? (Symbol.asyncIterator || (Symbol.asyncIterator = Symbol("Symbol.asyncIterator"))) : "@@asyncIterator";

// Asynchronously call a function and send errors to recovery continuation
function _catch(body, recover) {
	try {
		var result = body();
	} catch(e) {
		return recover(e);
	}
	if (result && result.then) {
		return result.then(void 0, recover);
	}
	return result;
}

/**
 *
 * @param corPID 公司的id
 * @param corSecret 你的应用的id
 * @param agentid 你的应用的id
 */

var WechatWorkBase =
/*#__PURE__*/
function () {
  function WechatWorkBase(corPID, corSecret, agentid) {
    this.accessToken = '';
    this.accessTokenExpireAt = 0;
    this.agentid = 0;
    this.accessTokenURL = 'https://qyapi.weixin.qq.com/cgi-bin/gettoken';
    this.messageSendURL = 'https://qyapi.weixin.qq.com/cgi-bin/message/send';
    this.isUpdating = false;
    this.corPID = corPID;
    this.corSecret = corSecret;
    this.agentid = agentid;
    this.axios = axios;
  }
  /**
   * 获取token并且会存储缓存
   */


  var _proto = WechatWorkBase.prototype;

  _proto.GetAccessToken = function GetAccessToken() {
    try {
      var _this2 = this;

      var _temp4 = function _temp4() {
        // 解除更新状态
        _this2.isUpdating = false;
        return _this2.accessToken;
      };

      var currentDate = +new Date(); // 当前时间大于过期时间且未处于正在刷新状态

      var _temp5 = function () {
        if (_this2.accessTokenExpireAt < currentDate || _this2.isUpdating === false) {
          // 正在处于刷新 防止单个实例并发
          _this2.isUpdating = true;
          var params = {
            corpid: _this2.corPID,
            corpsecret: _this2.corSecret
          };

          var _temp6 = _catch(function () {
            return Promise.resolve(_this2.axios.get(_this2.accessTokenURL, {
              params: params
            })).then(function (_ref) {
              var _ref$data = _ref.data,
                  errcode = _ref$data.errcode,
                  access_token = _ref$data.access_token,
                  expires_in = _ref$data.expires_in;

              if (errcode === 0) {
                _this2.accessToken = access_token;
                _this2.accessTokenExpireAt = currentDate + expires_in * 1000 - 20000;
              }
            });
          }, function (error) {
            console.log(error);
          });

          if (_temp6 && _temp6.then) return _temp6.then(function () {});
        }
      }();

      return _temp5 && _temp5.then ? _temp5.then(_temp4) : _temp4(_temp5);
    } catch (e) {
      return Promise.reject(e);
    }
  };

  return WechatWorkBase;
}();

var WechatWorkPush =
/*#__PURE__*/
function (_WechatWorkBase) {
  _inheritsLoose(WechatWorkPush, _WechatWorkBase);

  function WechatWorkPush() {
    return _WechatWorkBase.apply(this, arguments) || this;
  }

  var _proto = WechatWorkPush.prototype;

  /**
   * 最简单版本的发送消息 什么都不管你 自己玩
   *
   * @param data {MessageBody} 发送主体
   */
  _proto.PushMessage = function PushMessage(data) {
    try {
      var _this12 = this;

      // 我要给你写业务逻辑吗...
      return Promise.resolve(_this12.GetAccessToken()).then(function (token) {
        return Promise.resolve(_this12.axios.post(_this12.messageSendURL + "?access_token=" + token, data)).then(function (_ref) {
          var res = _ref.data;
          return res;
        });
      });
    } catch (e) {
      return Promise.reject(e);
    }
  };

  _proto.SetDefaultValue = function SetDefaultValue(obj) {
    var modify = Object.assign({
      touser: '@all',
      toparty: '',
      totag: '',
      safe: 0
    }, obj);
    return modify;
  }
  /**
   * 发送文本消息
   *
   * @param {object} param0 touser toparty totag 不传值默认发送给所有人
   *
   * @param {string} [param0.touser='@all'] - 成员ID列表（消息接收者，多个接收者用‘|’分隔，最多支持1000个）。特殊情况：指定为 "@all"，则向关注该企业应用的全部成员发送
   *
   * @param {string} [param0.toparty]
   * 部门ID列表，多个接收者用‘|’分隔，最多支持100个。当touser为 "@all"
   * 时忽略本参数
   *
   * @param {string} [param0.totag]
   * 标签ID列表，多个接收者用‘|’分隔，最多支持100个。当touser为 "@all"
   * 时忽略本参数
   *
   * @param {string} param0.text.content
   * 消息内容，最长不超过2048个字节，超过将截断
   *
   * @param {number} param0.safe
   * 表示是否是保密消息，0表示否，1表示是，默认0
   */
  ;

  _proto.PushMessageText = function PushMessageText(data) {
    try {
      var _this13 = this;

      data = _this13.SetDefaultValue(data);
      return Promise.resolve(_this13.PushMessage(_extends({}, data, {
        agentid: _this13.agentid,
        msgtype: 'text'
      })));
    } catch (e) {
      return Promise.reject(e);
    }
  }
  /**
   * 发送Markdown文本消息
   *
   * @param {object} param0 touser toparty totag 不传值默认发送给所有人
   *
   * @param {string} [param0.touser='@all'] - 成员ID列表（消息接收者，多个接收者用‘|’分隔，最多支持1000个）。特殊情况：指定为 "@all"，则向关注该企业应用的全部成员发送
   *
   * @param {string} [param0.toparty]
   * 部门ID列表，多个接收者用‘|’分隔，最多支持100个。当touser为 "@all"
   * 时忽略本参数
   *
   * @param {string} [param0.totag]
   * 标签ID列表，多个接收者用‘|’分隔，最多支持100个。当touser为 "@all"
   * 时忽略本参数
   *
   * @param {string} param0.text.content
   * 消息内容，最长不超过2048个字节，超过将截断
   *
   * @param {number} param0.safe
   * 表示是否是保密消息，0表示否，1表示是，默认0
   */
  ;

  _proto.PushMessageMarkdown = function PushMessageMarkdown(data) {
    try {
      var _this14 = this;

      data = _this14.SetDefaultValue(data);
      return Promise.resolve(_this14.PushMessage(_extends({}, data, {
        agentid: _this14.agentid,
        msgtype: 'markdown'
      })));
    } catch (e) {
      return Promise.reject(e);
    }
  }
  /**
   * 发送图片消息
   *
   * @param {object} param0 touser toparty totag 不传值默认发送给所有人
   *
   * @param {string} [param0.touser='@all'] - 成员ID列表（消息接收者，多个接收者用‘|’分隔，最多支持1000个）。特殊情况：指定为 "@all"，则向关注该企业应用的全部成员发送
   *
   * @param {string} [param0.toparty]
   * 部门ID列表，多个接收者用‘|’分隔，最多支持100个。当touser为 "@all"
   * 时忽略本参数
   *
   * @param {string} [param0.totag]
   * 标签ID列表，多个接收者用‘|’分隔，最多支持100个。当touser为 "@all"
   * 时忽略本参数
   *
   * @param {string} param0.image.media_id
   * 媒体文件id，可以调用上传临时素材接口获取
   *
   * @param {number} param0.safe
   * 表示是否是保密消息，0表示否，1表示是，默认0
   */
  ;

  _proto.PushMessageImage = function PushMessageImage(data) {
    try {
      var _this15 = this;

      data = _this15.SetDefaultValue(data);
      return Promise.resolve(_this15.PushMessage(_extends({}, data, {
        agentid: _this15.agentid,
        msgtype: 'image'
      })));
    } catch (e) {
      return Promise.reject(e);
    }
  }
  /**
   * 发送语音消息
   *
   * @param {object} param0 touser toparty totag 不传值默认发送给所有人
   *
   * @param {string} [param0.touser='@all'] - 成员ID列表（消息接收者，多个接收者用‘|’分隔，最多支持1000个）。特殊情况：指定为 "@all"，则向关注该企业应用的全部成员发送
   *
   * @param {string} [param0.toparty]
   * 部门ID列表，多个接收者用‘|’分隔，最多支持100个。当touser为 "@all"
   * 时忽略本参数
   *
   * @param {string} [param0.totag]
   * 标签ID列表，多个接收者用‘|’分隔，最多支持100个。当touser为 "@all"
   * 时忽略本参数
   *
   * @param {string} param0.voice.media_id
   * 媒体文件id，可以调用上传临时素材接口获取
   *
   * @param {number} param0.safe
   * 表示是否是保密消息，0表示否，1表示是，默认0
   */
  ;

  _proto.PushMessageVoice = function PushMessageVoice(data) {
    try {
      var _this16 = this;

      var _data$touser = data.touser,
          touser = _data$touser === void 0 ? '@all' : _data$touser,
          _data$toparty = data.toparty,
          toparty = _data$toparty === void 0 ? '' : _data$toparty,
          _data$totag = data.totag,
          totag = _data$totag === void 0 ? '' : _data$totag,
          _data$safe = data.safe,
          safe = _data$safe === void 0 ? 0 : _data$safe,
          voice = data.voice;
      return Promise.resolve(_this16.PushMessage({
        touser: touser,
        toparty: toparty,
        totag: totag,
        safe: safe,
        agentid: _this16.agentid,
        msgtype: 'voice',
        voice: voice
      }));
    } catch (e) {
      return Promise.reject(e);
    }
  }
  /**
   * 发送视频消息
   *
   * @param {object} param0 touser toparty totag 不传值默认发送给所有人
   *
   * @param {string} [param0.touser='@all'] - 成员ID列表（消息接收者，多个接收者用‘|’分隔，最多支持1000个）。特殊情况：指定为 "@all"，则向关注该企业应用的全部成员发送
   *
   * @param {string} [param0.toparty]
   * 部门ID列表，多个接收者用‘|’分隔，最多支持100个。当touser为 "@all"
   * 时忽略本参数
   *
   * @param {string} [param0.totag]
   * 标签ID列表，多个接收者用‘|’分隔，最多支持100个。当touser为 "@all"
   * 时忽略本参数
   *
   * @param {string} param0.video.media_id
   * 媒体文件id，可以调用上传临时素材接口获取
   *
   * @param {string} [param0.video.title]
   * 消息标题
   *
   * @param {string} [param0.video.description]
   * 消息描述
   *
   * @param {number} param0.safe
   * 表示是否是保密消息，0表示否，1表示是，默认0
   */
  ;

  _proto.PushMessageVideo = function PushMessageVideo(data) {
    try {
      var _this17 = this;

      var _data$touser2 = data.touser,
          touser = _data$touser2 === void 0 ? '@all' : _data$touser2,
          _data$toparty2 = data.toparty,
          toparty = _data$toparty2 === void 0 ? '' : _data$toparty2,
          _data$totag2 = data.totag,
          totag = _data$totag2 === void 0 ? '' : _data$totag2,
          _data$safe2 = data.safe,
          safe = _data$safe2 === void 0 ? 0 : _data$safe2,
          video = data.video;
      return Promise.resolve(_this17.PushMessage({
        touser: touser,
        toparty: toparty,
        totag: totag,
        safe: safe,
        agentid: _this17.agentid,
        msgtype: 'video',
        video: video
      }));
    } catch (e) {
      return Promise.reject(e);
    }
  }
  /**
   * 发送视频消息
   *
   * @param {object} param0 touser toparty totag 不传值默认发送给所有人
   *
   * @param {string} [param0.touser='@all'] - 成员ID列表（消息接收者，多个接收者用‘|’分隔，最多支持1000个）。特殊情况：指定为 "@all"，则向关注该企业应用的全部成员发送
   *
   * @param {string} [param0.toparty]
   * 部门ID列表，多个接收者用‘|’分隔，最多支持100个。当touser为 "@all"
   * 时忽略本参数
   *
   * @param {string} [param0.totag]
   * 标签ID列表，多个接收者用‘|’分隔，最多支持100个。当touser为 "@all"
   * 时忽略本参数
   *
   * @param {string} param0.file.media_id
   * 媒体文件id，可以调用上传临时素材接口获取
   *
   * @param {number} param0.safe
   * 表示是否是保密消息，0表示否，1表示是，默认0
   */
  ;

  _proto.PushMessageFile = function PushMessageFile(data) {
    try {
      var _this18 = this;

      var _data$touser3 = data.touser,
          touser = _data$touser3 === void 0 ? '@all' : _data$touser3,
          _data$toparty3 = data.toparty,
          toparty = _data$toparty3 === void 0 ? '' : _data$toparty3,
          _data$totag3 = data.totag,
          totag = _data$totag3 === void 0 ? '' : _data$totag3,
          _data$safe3 = data.safe,
          safe = _data$safe3 === void 0 ? 0 : _data$safe3,
          file = data.file;
      return Promise.resolve(_this18.PushMessage({
        touser: touser,
        toparty: toparty,
        totag: totag,
        safe: safe,
        agentid: _this18.agentid,
        msgtype: 'file',
        file: file
      }));
    } catch (e) {
      return Promise.reject(e);
    }
  }
  /**
   * 发送文本卡片消息
   *
   * @param {object} param0 touser toparty totag 不传值默认发送给所有人
   *
   * @param {string} [param0.touser='@all'] - 成员ID列表（消息接收者，多个接收者用‘|’分隔，最多支持1000个）。特殊情况：指定为 "@all"，则向关注该企业应用的全部成员发送
   *
   * @param {string} [param0.toparty]
   * 部门ID列表，多个接收者用‘|’分隔，最多支持100个。当touser为 "@all"
   * 时忽略本参数
   *
   * @param {string} [param0.totag]
   * 标签ID列表，多个接收者用‘|’分隔，最多支持100个。当touser为 "@all"
   * 时忽略本参数
   *
   * @param {string} param0.textcard.title
   * 消息标题
   *
   * @param {string} param0.textcard.description
   * 消息描述
   *
   * @param {string} param0.textcard.url
   * 消息跳转地址
   *
   * @param {string} [param0.textcard.btntxt="详情"]
   * 消息跳转地址文本描述
   *
   * @param {number} param0.safe
   * 表示是否是保密消息，0表示否，1表示是，默认0
   */
  ;

  _proto.PushMessageTextcard = function PushMessageTextcard(data) {
    try {
      var _this19 = this;

      var _data$touser4 = data.touser,
          touser = _data$touser4 === void 0 ? '@all' : _data$touser4,
          _data$toparty4 = data.toparty,
          toparty = _data$toparty4 === void 0 ? '' : _data$toparty4,
          _data$totag4 = data.totag,
          totag = _data$totag4 === void 0 ? '' : _data$totag4,
          _data$safe4 = data.safe,
          safe = _data$safe4 === void 0 ? 0 : _data$safe4,
          textcard = data.textcard;
      return Promise.resolve(_this19.PushMessage({
        touser: touser,
        toparty: toparty,
        totag: totag,
        safe: safe,
        agentid: _this19.agentid,
        msgtype: 'textcard',
        textcard: textcard
      }));
    } catch (e) {
      return Promise.reject(e);
    }
  }
  /**
   * 发送图文消息
   *
   * @param {object} param0 touser toparty totag 不传值默认发送给所有人
   *
   * @param {string} [param0.touser='@all'] - 成员ID列表（消息接收者，多个接收者用‘|’分隔，最多支持1000个）。特殊情况：指定为 "@all"，则向关注该企业应用的全部成员发送
   *
   * @param {string} [param0.toparty]
   * 部门ID列表，多个接收者用‘|’分隔，最多支持100个。当touser为 "@all"
   * 时忽略本参数
   *
   * @param {string} [param0.totag]
   * 标签ID列表，多个接收者用‘|’分隔，最多支持100个。当touser为 "@all"
   * 时忽略本参数
   *
   * @param {Object} param0.news
   * 图文消息new属性
   *
   * @param {Array} param0.news.articles
   * 图文列表
   *
   * @param {string} param0.news.articles.title
   * 图文列表元素标题
   *
   * @param {string} [param0.news.articles.description]
   * 图文列表元素描述
   *
   * @param {string} param0.news.articles.url
   * 图文列表元素点击后跳转的链接。
   *
   * @param {string} [param0.news.articles.picurl]
   * 图文列表元素图片链接。
   *
   * @param {number} param0.safe
   * 表示是否是保密消息，0表示否，1表示是，默认0
   */
  ;

  _proto.PushMessageNews = function PushMessageNews(data) {
    try {
      var _this20 = this;

      var _data$touser5 = data.touser,
          touser = _data$touser5 === void 0 ? '@all' : _data$touser5,
          _data$toparty5 = data.toparty,
          toparty = _data$toparty5 === void 0 ? '' : _data$toparty5,
          _data$totag5 = data.totag,
          totag = _data$totag5 === void 0 ? '' : _data$totag5,
          _data$safe5 = data.safe,
          safe = _data$safe5 === void 0 ? 0 : _data$safe5,
          news = data.news;
      return Promise.resolve(_this20.PushMessage({
        touser: touser,
        toparty: toparty,
        totag: totag,
        safe: safe,
        agentid: _this20.agentid,
        msgtype: 'news',
        news: news
      }));
    } catch (e) {
      return Promise.reject(e);
    }
  }
  /**
   * 发送资源存储于企业微信的图文消息
   *
   * @param {object} param0 touser toparty totag 不传值默认发送给所有人
   *
   * @param {string} [param0.touser='@all'] - 成员ID列表（消息接收者，多个接收者用‘|’分隔，最多支持1000个）。特殊情况：指定为 "@all"，则向关注该企业应用的全部成员发送
   *
   * @param {string} [param0.toparty]
   * 部门ID列表，多个接收者用‘|’分隔，最多支持100个。当touser为 "@all"
   * 时忽略本参数
   *
   * @param {string} [param0.totag]
   * 标签ID列表，多个接收者用‘|’分隔，最多支持100个。当touser为 "@all"
   * 时忽略本参数
   *
   * @param {Object} param0.mpnews
   * 图文消息new属性
   *
   * @param {Array} param0.mpnews.articles
   * 图文列表
   *
   * @param {string} param0.mpnews.articles.title
   * 图文列表元素标题
   *
   * @param {string} param0.mpnews.articles.thumb_media_id
   * 图文列表元素缩略图id
   *
   * @param {string} param0.mpnews.articles.content
   * 图文列表元素内容
   *
   * @param {string} [param0.mpnews.articles.digest]
   * 图文列表元素描述
   *
   * @param {string} [param0.mpnews.articles.author]
   * 图文列表元素作者
   *
   * @param {string} [param0.mpnews.articles.content_source_url]
   * 图文列表元素点击后跳转的链接。
   *
   * @param {number} param0.safe
   * 表示是否是保密消息，0表示否，1表示是，默认0
   */
  ;

  _proto.PushMessageMPnews = function PushMessageMPnews(data) {
    try {
      var _this21 = this;

      var _data$touser6 = data.touser,
          touser = _data$touser6 === void 0 ? '@all' : _data$touser6,
          _data$toparty6 = data.toparty,
          toparty = _data$toparty6 === void 0 ? '' : _data$toparty6,
          _data$totag6 = data.totag,
          totag = _data$totag6 === void 0 ? '' : _data$totag6,
          _data$safe6 = data.safe,
          safe = _data$safe6 === void 0 ? 0 : _data$safe6,
          mpnews = data.mpnews;
      return Promise.resolve(_this21.PushMessage({
        touser: touser,
        toparty: toparty,
        totag: totag,
        safe: safe,
        agentid: _this21.agentid,
        msgtype: 'mpnews',
        mpnews: mpnews
      }));
    } catch (e) {
      return Promise.reject(e);
    }
  }
  /**
   * 发送小程序推送消息 / 只能小程序类型的推送 不支持全员推送
   *
   * @param {object} param0 touser toparty totag
   *
   * @param {string} [param0.touser] - 成员ID列表（消息接收者，多个接收者用‘|’分隔，最多支持1000个）。特殊情况：指定为 "@all"，则向关注该企业应用的全部成员发送
   *
   * @param {string} [param0.toparty]
   * 部门ID列表，多个接收者用‘|’分隔，最多支持100个。当touser为 "@all"
   * 时忽略本参数
   *
   * @param {string} [param0.totag]
   * 标签ID列表，多个接收者用‘|’分隔，最多支持100个。当touser为 "@all"
   * 时忽略本参数
   *
   * @param {Object} param0.miniprogram_notice
   * 小程序消息
   *
   * @param {string} param0.miniprogram_notice.title
   * 消息标题
   *
   * @param {string} param0.miniprogram_notice.appid
   * 小程序id
   *
   * @param {string} [param0.miniprogram_notice.page]
   * 点击消息卡片后的小程序页面，仅限本小程序内的页面。该字段不填则消息点击后不跳转。
   *
   * @param {string} [param0.miniprogram_notice.description]
   * 消息描述
   *
   * @param {Boolean} [param0.miniprogram_notice.emphasis_first_item]
   * 是否放大第一个
   *
   * @param {Array} [param0.miniprogram_notice.content_item]
   * 消息键值对列表 [{"key":"value"}]
   *
   */
  ;

  _proto.PushMessageMiniProgram = function PushMessageMiniProgram(data) {
    try {
      var _this22 = this;

      var _data$touser7 = data.touser,
          touser = _data$touser7 === void 0 ? '@all' : _data$touser7,
          _data$toparty7 = data.toparty,
          toparty = _data$toparty7 === void 0 ? '' : _data$toparty7,
          _data$totag7 = data.totag,
          totag = _data$totag7 === void 0 ? '' : _data$totag7,
          miniprogram_notice = data.miniprogram_notice;
      return Promise.resolve(_this22.PushMessage({
        touser: touser,
        toparty: toparty,
        totag: totag,
        msgtype: 'miniprogram_notice',
        miniprogram_notice: miniprogram_notice
      }));
    } catch (e) {
      return Promise.reject(e);
    }
  };

  return WechatWorkPush;
}(WechatWorkBase);

/**
 * 素材管理接口
 */

var WechatWorkMedia =
/*#__PURE__*/
function (_WechatWorkBase) {
  _inheritsLoose(WechatWorkMedia, _WechatWorkBase);

  function WechatWorkMedia() {
    var _this5;

    _this5 = _WechatWorkBase.apply(this, arguments) || this;
    _this5.mediaURL = 'https://qyapi.weixin.qq.com/cgi-bin/media/upload';
    _this5.mediaDurableURL = 'https://qyapi.weixin.qq.com/cgi-bin/media/uploadimg';
    _this5.mediaTempGetURL = 'https://qyapi.weixin.qq.com/cgi-bin/media/get';
    _this5.mediaHightQualityVoiceURL = 'https://qyapi.weixin.qq.com/cgi-bin/media/get/jssdk';
    return _this5;
  }
  /**
   * 上传临时文件
   *
   * @param Formdata 文件数据
   * @param type 类型
   */


  var _proto = WechatWorkMedia.prototype;

  _proto.PostMediaTempSource = function PostMediaTempSource(Formdata, type) {
    try {
      var _this6 = this;

      return Promise.resolve(_this6.GetAccessToken()).then(function (token) {
        return Promise.resolve(_this6.axios({
          method: 'POST',
          url: _this6.mediaURL,
          headers: {
            'Content-Type': 'multipart/form-data'
          },
          params: {
            access_token: token,
            type: type
          },
          data: Formdata
        })).then(function (_ref) {
          var data = _ref.data;
          return data;
        });
      });
    } catch (e) {
      return Promise.reject(e);
    }
  }
  /**
   * 上传永久图片
   *
   * @param Formdata 文件数据
   */
  ;

  _proto.PostMediaDurablePicture = function PostMediaDurablePicture(Formdata) {
    try {
      var _this7 = this;

      return Promise.resolve(_this7.GetAccessToken()).then(function (token) {
        return Promise.resolve(_this7.axios({
          url: _this7.mediaDurableURL,
          method: 'POST',
          params: {
            access_token: token
          },
          headers: {
            'Content-Type': 'multipart/form-data'
          },
          data: Formdata
        })).then(function (_ref2) {
          var data = _ref2.data;
          return data;
        });
      });
    } catch (e) {
      return Promise.reject(e);
    }
  }
  /**
   * 下载临时素材
   *
   * @param {string} media_id 媒体文件id
   */
  ;

  _proto.GetMediaTempSource = function GetMediaTempSource(media_id) {
    try {
      var _this8 = this;

      return Promise.resolve(_this8.GetAccessToken()).then(function (token) {
        return _this8.axios.get(_this8.mediaTempGetURL, {
          params: {
            access_token: token,
            media_id: media_id
          }
        });
      });
    } catch (e) {
      return Promise.reject(e);
    }
  }
  /**
   * 获取高清语音素材
   *
   * @param {string} media_id 媒体文件id
   */
  ;

  _proto.GetMediaHighQualityVoice = function GetMediaHighQualityVoice(media_id) {
    try {
      var _this9 = this;

      return Promise.resolve(_this9.GetAccessToken()).then(function (token) {
        return _this9.axios.get(_this9.mediaHightQualityVoiceURL, {
          params: {
            access_token: token,
            media_id: media_id
          }
        });
      });
    } catch (e) {
      return Promise.reject(e);
    }
  };

  return WechatWorkMedia;
}(WechatWorkBase);

var index = {
  WechatWorkPush: WechatWorkPush,
  WechatWorkMedia: WechatWorkMedia
};

exports.default = index;
//# sourceMappingURL=wechatwork-sdk.cjs.development.js.map
